@@ -1,6 +1,6 @@
 /*
  *  git2r, R bindings to the libgit2 library.
- *  Copyright (C) 2013-2015 The git2r contributors
+ *  Copyright (C) 2013-2023 The git2r contributors
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -21,9 +21,9 @@
 
 #include <R.h>
 #include <Rinternals.h>
-#include "git2.h"
+#include <git2.h>
 
-SEXP git2r_blob_content(SEXP blob);
+SEXP git2r_blob_content(SEXP blob, SEXP raw);
 SEXP git2r_blob_create_fromdisk(SEXP repo, SEXP path);
 SEXP git2r_blob_create_fromworkdir(SEXP repo, SEXP relative_path);
 void git2r_blob_init(const git_blob *source, SEXP repo, SEXP dest);
